@@ -16,7 +16,7 @@ namespace  {
 
 struct Magick_DrawableStrokeLineJoin_Wrapper: Magick::DrawableStrokeLineJoin
 {
-    Magick_DrawableStrokeLineJoin_Wrapper(PyObject* py_self_, MagickLib::LineJoin p0):
+    Magick_DrawableStrokeLineJoin_Wrapper(PyObject* py_self_, MagickCore::LineJoin p0):
         Magick::DrawableStrokeLineJoin(p0), py_self(py_self_) {}
 
 
@@ -30,9 +30,9 @@ struct Magick_DrawableStrokeLineJoin_Wrapper: Magick::DrawableStrokeLineJoin
 // Module ======================================================================
 void Export_pyste_src_DrawableStrokeLineJoin()
 {
-    class_< Magick::DrawableStrokeLineJoin, boost::noncopyable, Magick_DrawableStrokeLineJoin_Wrapper >("DrawableStrokeLineJoin", init< MagickLib::LineJoin >())
-        .def("linejoin", (void (Magick::DrawableStrokeLineJoin::*)(MagickLib::LineJoin) )&Magick::DrawableStrokeLineJoin::linejoin)
-        .def("linejoin", (MagickLib::LineJoin (Magick::DrawableStrokeLineJoin::*)() const)&Magick::DrawableStrokeLineJoin::linejoin)
+    class_< Magick::DrawableStrokeLineJoin, boost::noncopyable, Magick_DrawableStrokeLineJoin_Wrapper >("DrawableStrokeLineJoin", init< MagickCore::LineJoin >())
+        .def("linejoin", (void (Magick::DrawableStrokeLineJoin::*)(MagickCore::LineJoin) )&Magick::DrawableStrokeLineJoin::linejoin)
+        .def("linejoin", (MagickCore::LineJoin (Magick::DrawableStrokeLineJoin::*)() const)&Magick::DrawableStrokeLineJoin::linejoin)
     ;
 
 }
