@@ -73,30 +73,30 @@ void Export_pyste_src_Image()
         .def(init< const Magick::Blob&, const Magick::Geometry&, const unsigned int >())
         .def(init< const Magick::Blob&, const Magick::Geometry&, const unsigned int, const std::string& >())
         .def(init< const Magick::Blob&, const Magick::Geometry&, const std::string& >())
-        .def(init< const unsigned int, const unsigned int, const std::string&, const MagickLib::StorageType, const void* >())
+        .def(init< const unsigned int, const unsigned int, const std::string&, const MagickCore::StorageType, const void* >())
         .def(init< const Magick::Image& >())
-        .def(init< MagickLib::Image* >())
+        .def(init< MagickCore::Image* >())
         .def("adaptiveThreshold", &Magick::Image::adaptiveThreshold, Magick_Image_adaptiveThreshold_overloads_2_3())
         .def("addNoise", &Magick::Image::addNoise)
         .def("affineTransform", &Magick::Image::affineTransform)
         .def("annotate", (void (Magick::Image::*)(const std::string&, const Magick::Geometry&) )&Magick::Image::annotate)
-        .def("annotate", (void (Magick::Image::*)(const std::string&, const Magick::Geometry&, const MagickLib::GravityType) )&Magick::Image::annotate)
-        .def("annotate", (void (Magick::Image::*)(const std::string&, const Magick::Geometry&, const MagickLib::GravityType, const double) )&Magick::Image::annotate)
-        .def("annotate", (void (Magick::Image::*)(const std::string&, const MagickLib::GravityType) )&Magick::Image::annotate)
+        .def("annotate", (void (Magick::Image::*)(const std::string&, const Magick::Geometry&, const MagickCore::GravityType) )&Magick::Image::annotate)
+        .def("annotate", (void (Magick::Image::*)(const std::string&, const Magick::Geometry&, const MagickCore::GravityType, const double) )&Magick::Image::annotate)
+        .def("annotate", (void (Magick::Image::*)(const std::string&, const MagickCore::GravityType) )&Magick::Image::annotate)
         .def("blur", &Magick::Image::blur, Magick_Image_blur_overloads_0_2())
         .def("border", &Magick::Image::border, Magick_Image_border_overloads_0_1())
         .def("channel", &Magick::Image::channel)
-        .def("channelDepth", (void (Magick::Image::*)(const MagickLib::ChannelType, const unsigned int) )&Magick::Image::channelDepth)
-        .def("channelDepth", (unsigned int (Magick::Image::*)(const MagickLib::ChannelType) )&Magick::Image::channelDepth)
+        .def("channelDepth", (void (Magick::Image::*)(const MagickCore::ChannelType, const unsigned int) )&Magick::Image::channelDepth)
+        .def("channelDepth", (unsigned int (Magick::Image::*)(const MagickCore::ChannelType) )&Magick::Image::channelDepth)
         .def("charcoal", &Magick::Image::charcoal, Magick_Image_charcoal_overloads_0_2())
         .def("chop", &Magick::Image::chop)
         .def("colorize", (void (Magick::Image::*)(const unsigned int, const unsigned int, const unsigned int, const Magick::Color&) )&Magick::Image::colorize)
         .def("colorize", (void (Magick::Image::*)(const unsigned int, const Magick::Color&) )&Magick::Image::colorize)
         .def("comment", (void (Magick::Image::*)(const std::string&) )&Magick::Image::comment)
         .def("compare", &Magick::Image::compare)
-        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const int, const int, const MagickLib::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_3_4())
-        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const Magick::Geometry&, const MagickLib::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
-        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const MagickLib::GravityType, const MagickLib::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
+        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const int, const int, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_3_4())
+        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const Magick::Geometry&, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
+        .def("composite", (void (Magick::Image::*)(const Magick::Image&, const MagickCore::GravityType, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
         .def("contrast", &Magick::Image::contrast)
         .def("convolve", &Magick::Image::convolve)
         .def("crop", &Magick::Image::crop)
@@ -151,7 +151,7 @@ void Export_pyste_src_Image()
         .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const unsigned int) )&Magick::Image::read)
         .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const unsigned int, const std::string&) )&Magick::Image::read)
         .def("read", (void (Magick::Image::*)(const Magick::Blob&, const Magick::Geometry&, const std::string&) )&Magick::Image::read)
-        .def("read", (void (Magick::Image::*)(const unsigned int, const unsigned int, const std::string&, const MagickLib::StorageType, const void*) )&Magick::Image::read)
+        .def("read", (void (Magick::Image::*)(const unsigned int, const unsigned int, const std::string&, const MagickCore::StorageType, const void*) )&Magick::Image::read)
         .def("reduceNoise", (void (Magick::Image::*)() )&Magick::Image::reduceNoise)
         .def("reduceNoise", (void (Magick::Image::*)(const double) )&Magick::Image::reduceNoise)
         .def("roll", (void (Magick::Image::*)(const Magick::Geometry&) )&Magick::Image::roll)
@@ -175,14 +175,14 @@ void Export_pyste_src_Image()
         .def("transform", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Geometry&) )&Magick::Image::transform)
         .def("transparent", &Magick::Image::transparent)
         .def("trim", &Magick::Image::trim)
-        .def("type", (void (Magick::Image::*)(const MagickLib::ImageType) )&Magick::Image::type)
+        .def("type", (void (Magick::Image::*)(const MagickCore::ImageType) )&Magick::Image::type)
         .def("unsharpmask", &Magick::Image::unsharpmask)
         .def("wave", &Magick::Image::wave, Magick_Image_wave_overloads_0_2())
         .def("write", (void (Magick::Image::*)(const std::string&) )&Magick::Image::write)
         .def("write", (void (Magick::Image::*)(Magick::Blob*) )&Magick::Image::write)
         .def("write", (void (Magick::Image::*)(Magick::Blob*, const std::string&) )&Magick::Image::write)
         .def("write", (void (Magick::Image::*)(Magick::Blob*, const std::string&, const unsigned int) )&Magick::Image::write)
-        .def("write", (void (Magick::Image::*)(const int, const int, const unsigned int, const unsigned int, const std::string&, const MagickLib::StorageType, void*) )&Magick::Image::write)
+        .def("write", (void (Magick::Image::*)(const int, const int, const unsigned int, const unsigned int, const std::string&, const MagickCore::StorageType, void*) )&Magick::Image::write)
         .def("zoom", &Magick::Image::zoom)
         .def("adjoin", (void (Magick::Image::*)(const bool) )&Magick::Image::adjoin)
         .def("adjoin", (bool (Magick::Image::*)() const)&Magick::Image::adjoin)
@@ -215,8 +215,8 @@ void Export_pyste_src_Image()
         .def("chromaRedPrimary", (void (Magick::Image::*)(double*, double*) const)&Magick::Image::chromaRedPrimary)
         .def("chromaWhitePoint", (void (Magick::Image::*)(const double, const double) )&Magick::Image::chromaWhitePoint)
         .def("chromaWhitePoint", (void (Magick::Image::*)(double*, double*) const)&Magick::Image::chromaWhitePoint)
-        .def("classType", (void (Magick::Image::*)(const MagickLib::ClassType) )&Magick::Image::classType)
-        .def("classType", (MagickLib::ClassType (Magick::Image::*)() const)&Magick::Image::classType)
+        .def("classType", (void (Magick::Image::*)(const MagickCore::ClassType) )&Magick::Image::classType)
+        .def("classType", (MagickCore::ClassType (Magick::Image::*)() const)&Magick::Image::classType)
         .def("clipMask", (void (Magick::Image::*)(const Magick::Image&) )&Magick::Image::clipMask)
         .def("clipMask", (Magick::Image (Magick::Image::*)() const)&Magick::Image::clipMask)
         .def("colorFuzz", (void (Magick::Image::*)(const double) )&Magick::Image::colorFuzz)
@@ -225,14 +225,14 @@ void Export_pyste_src_Image()
         .def("colorMap", (Magick::Color (Magick::Image::*)(const unsigned int) const)&Magick::Image::colorMap)
         .def("colorMapSize", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::colorMapSize)
         .def("colorMapSize", (unsigned int (Magick::Image::*)() )&Magick::Image::colorMapSize)
-        .def("colorSpace", (void (Magick::Image::*)(const MagickLib::ColorspaceType) )&Magick::Image::colorSpace)
-        .def("colorSpace", (MagickLib::ColorspaceType (Magick::Image::*)() const)&Magick::Image::colorSpace)
+        .def("colorSpace", (void (Magick::Image::*)(const MagickCore::ColorspaceType) )&Magick::Image::colorSpace)
+        .def("colorSpace", (MagickCore::ColorspaceType (Magick::Image::*)() const)&Magick::Image::colorSpace)
         .def("columns", &Magick::Image::columns)
         .def("comment", (std::string (Magick::Image::*)() const)&Magick::Image::comment)
-        .def("compose", (void (Magick::Image::*)(const MagickLib::CompositeOperator) )&Magick::Image::compose)
-        .def("compose", (MagickLib::CompositeOperator (Magick::Image::*)() const)&Magick::Image::compose)
-        .def("compressType", (void (Magick::Image::*)(const MagickLib::CompressionType) )&Magick::Image::compressType)
-        .def("compressType", (MagickLib::CompressionType (Magick::Image::*)() const)&Magick::Image::compressType)
+        .def("compose", (void (Magick::Image::*)(const MagickCore::CompositeOperator) )&Magick::Image::compose)
+        .def("compose", (MagickCore::CompositeOperator (Magick::Image::*)() const)&Magick::Image::compose)
+        .def("compressType", (void (Magick::Image::*)(const MagickCore::CompressionType) )&Magick::Image::compressType)
+        .def("compressType", (MagickCore::CompressionType (Magick::Image::*)() const)&Magick::Image::compressType)
         .def("debug", (void (Magick::Image::*)(const bool) )&Magick::Image::debug)
         .def("debug", (bool (Magick::Image::*)() const)&Magick::Image::debug)
         .def("defineValue", (void (Magick::Image::*)(const std::string&, const std::string&, const std::string&) )&Magick::Image::defineValue)
@@ -244,19 +244,19 @@ void Export_pyste_src_Image()
         .def("depth", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::depth)
         .def("depth", (unsigned int (Magick::Image::*)() const)&Magick::Image::depth)
         .def("directory", &Magick::Image::directory)
-        .def("endian", (void (Magick::Image::*)(const MagickLib::EndianType) )&Magick::Image::endian)
-        .def("endian", (MagickLib::EndianType (Magick::Image::*)() const)&Magick::Image::endian)
+        .def("endian", (void (Magick::Image::*)(const MagickCore::EndianType) )&Magick::Image::endian)
+        .def("endian", (MagickCore::EndianType (Magick::Image::*)() const)&Magick::Image::endian)
         .def("fileName", (void (Magick::Image::*)(const std::string&) )&Magick::Image::fileName)
         .def("fileName", (std::string (Magick::Image::*)() const)&Magick::Image::fileName)
         .def("fileSize", &Magick::Image::fileSize)
         .def("fillColor", (void (Magick::Image::*)(const Magick::Color&) )&Magick::Image::fillColor)
         .def("fillColor", (Magick::Color (Magick::Image::*)() const)&Magick::Image::fillColor)
-        .def("fillRule", (void (Magick::Image::*)(const MagickLib::FillRule&) )&Magick::Image::fillRule)
-        .def("fillRule", (MagickLib::FillRule (Magick::Image::*)() const)&Magick::Image::fillRule)
+        .def("fillRule", (void (Magick::Image::*)(const MagickCore::FillRule&) )&Magick::Image::fillRule)
+        .def("fillRule", (MagickCore::FillRule (Magick::Image::*)() const)&Magick::Image::fillRule)
         .def("fillPattern", (void (Magick::Image::*)(const Magick::Image&) )&Magick::Image::fillPattern)
         .def("fillPattern", (Magick::Image (Magick::Image::*)() const)&Magick::Image::fillPattern)
-        .def("filterType", (void (Magick::Image::*)(const MagickLib::FilterTypes) )&Magick::Image::filterType)
-        .def("filterType", (MagickLib::FilterTypes (Magick::Image::*)() const)&Magick::Image::filterType)
+        .def("filterType", (void (Magick::Image::*)(const MagickCore::FilterTypes) )&Magick::Image::filterType)
+        .def("filterType", (MagickCore::FilterTypes (Magick::Image::*)() const)&Magick::Image::filterType)
         .def("font", (void (Magick::Image::*)(const std::string&) )&Magick::Image::font)
         .def("font", (std::string (Magick::Image::*)() const)&Magick::Image::font)
         .def("fontPointsize", (void (Magick::Image::*)(const double) )&Magick::Image::fontPointsize)
@@ -269,8 +269,8 @@ void Export_pyste_src_Image()
         .def("gifDisposeMethod", (unsigned int (Magick::Image::*)() const)&Magick::Image::gifDisposeMethod)
         .def("iccColorProfile", (void (Magick::Image::*)(const Magick::Blob&) )&Magick::Image::iccColorProfile)
         .def("iccColorProfile", (Magick::Blob (Magick::Image::*)() const)&Magick::Image::iccColorProfile)
-        .def("interlaceType", (void (Magick::Image::*)(const MagickLib::InterlaceType) )&Magick::Image::interlaceType)
-        .def("interlaceType", (MagickLib::InterlaceType (Magick::Image::*)() const)&Magick::Image::interlaceType)
+        .def("interlaceType", (void (Magick::Image::*)(const MagickCore::InterlaceType) )&Magick::Image::interlaceType)
+        .def("interlaceType", (MagickCore::InterlaceType (Magick::Image::*)() const)&Magick::Image::interlaceType)
         .def("iptcProfile", (void (Magick::Image::*)(const Magick::Blob&) )&Magick::Image::iptcProfile)
         .def("iptcProfile", (Magick::Blob (Magick::Image::*)() const)&Magick::Image::iptcProfile)
         .def("isValid", (void (Magick::Image::*)(const bool) )&Magick::Image::isValid)
@@ -306,16 +306,16 @@ void Export_pyste_src_Image()
         .def("quality", (unsigned int (Magick::Image::*)() const)&Magick::Image::quality)
         .def("quantizeColors", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::quantizeColors)
         .def("quantizeColors", (unsigned int (Magick::Image::*)() const)&Magick::Image::quantizeColors)
-        .def("quantizeColorSpace", (void (Magick::Image::*)(const MagickLib::ColorspaceType) )&Magick::Image::quantizeColorSpace)
-        .def("quantizeColorSpace", (MagickLib::ColorspaceType (Magick::Image::*)() const)&Magick::Image::quantizeColorSpace)
+        .def("quantizeColorSpace", (void (Magick::Image::*)(const MagickCore::ColorspaceType) )&Magick::Image::quantizeColorSpace)
+        .def("quantizeColorSpace", (MagickCore::ColorspaceType (Magick::Image::*)() const)&Magick::Image::quantizeColorSpace)
         .def("quantizeDither", (void (Magick::Image::*)(const bool) )&Magick::Image::quantizeDither)
         .def("quantizeDither", (bool (Magick::Image::*)() const)&Magick::Image::quantizeDither)
         .def("quantizeTreeDepth", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::quantizeTreeDepth)
         .def("quantizeTreeDepth", (unsigned int (Magick::Image::*)() const)&Magick::Image::quantizeTreeDepth)
-        .def("renderingIntent", (void (Magick::Image::*)(const MagickLib::RenderingIntent) )&Magick::Image::renderingIntent)
-        .def("renderingIntent", (MagickLib::RenderingIntent (Magick::Image::*)() const)&Magick::Image::renderingIntent)
-        .def("resolutionUnits", (void (Magick::Image::*)(const MagickLib::ResolutionType) )&Magick::Image::resolutionUnits)
-        .def("resolutionUnits", (MagickLib::ResolutionType (Magick::Image::*)() const)&Magick::Image::resolutionUnits)
+        .def("renderingIntent", (void (Magick::Image::*)(const MagickCore::RenderingIntent) )&Magick::Image::renderingIntent)
+        .def("renderingIntent", (MagickCore::RenderingIntent (Magick::Image::*)() const)&Magick::Image::renderingIntent)
+        .def("resolutionUnits", (void (Magick::Image::*)(const MagickCore::ResolutionType) )&Magick::Image::resolutionUnits)
+        .def("resolutionUnits", (MagickCore::ResolutionType (Magick::Image::*)() const)&Magick::Image::resolutionUnits)
         .def("rows", &Magick::Image::rows)
         .def("scene", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::scene)
         .def("scene", (unsigned int (Magick::Image::*)() const)&Magick::Image::scene)
@@ -329,10 +329,10 @@ void Export_pyste_src_Image()
         .def("strokeColor", (Magick::Color (Magick::Image::*)() const)&Magick::Image::strokeColor)
         .def("strokeDashOffset", (void (Magick::Image::*)(const double) )&Magick::Image::strokeDashOffset)
         .def("strokeDashOffset", (double (Magick::Image::*)() const)&Magick::Image::strokeDashOffset)
-        .def("strokeLineCap", (void (Magick::Image::*)(const MagickLib::LineCap) )&Magick::Image::strokeLineCap)
-        .def("strokeLineCap", (MagickLib::LineCap (Magick::Image::*)() const)&Magick::Image::strokeLineCap)
-        .def("strokeLineJoin", (void (Magick::Image::*)(const MagickLib::LineJoin) )&Magick::Image::strokeLineJoin)
-        .def("strokeLineJoin", (MagickLib::LineJoin (Magick::Image::*)() const)&Magick::Image::strokeLineJoin)
+        .def("strokeLineCap", (void (Magick::Image::*)(const MagickCore::LineCap) )&Magick::Image::strokeLineCap)
+        .def("strokeLineCap", (MagickCore::LineCap (Magick::Image::*)() const)&Magick::Image::strokeLineCap)
+        .def("strokeLineJoin", (void (Magick::Image::*)(const MagickCore::LineJoin) )&Magick::Image::strokeLineJoin)
+        .def("strokeLineJoin", (MagickCore::LineJoin (Magick::Image::*)() const)&Magick::Image::strokeLineJoin)
         .def("strokeMiterLimit", (void (Magick::Image::*)(const unsigned int) )&Magick::Image::strokeMiterLimit)
         .def("strokeMiterLimit", (unsigned int (Magick::Image::*)() const)&Magick::Image::strokeMiterLimit)
         .def("strokePattern", (void (Magick::Image::*)(const Magick::Image&) )&Magick::Image::strokePattern)
@@ -354,7 +354,6 @@ void Export_pyste_src_Image()
         .def("transformScale", &Magick::Image::transformScale)
         .def("transformSkewX", &Magick::Image::transformSkewX)
         .def("transformSkewY", &Magick::Image::transformSkewY)
-        .def("type", (MagickLib::ImageType (Magick::Image::*)() const)&Magick::Image::type)
         .def("verbose", (void (Magick::Image::*)(const bool) )&Magick::Image::verbose)
         .def("verbose", (bool (Magick::Image::*)() const)&Magick::Image::verbose)
         .def("view", (void (Magick::Image::*)(const std::string&) )&Magick::Image::view)
